@@ -61,7 +61,7 @@ class Freebox(IPlugin):
 				if rs['idx_sec'] <> "1":
 					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre   len(maliste)  
-					for rang in range(len(rs['idx'])
+					for rang in range(len(rs['idx']))
 						if rs['idx'][rang] == '|':
 							rangs.append(rang)
 							log.msg(" rang  :  %s" % (rangs)
